@@ -210,62 +210,53 @@ def md5(
     return hashlib.md5(data).hexdigest()
 
 
-def rename(
-    file: str=None,
-    *,
-    filepath: str=None,
-    filename: str=None,
-    suffix: str=None
-) -> typing.Tuple[str, str, str]:
+def rename_file(file: str, *, suffix: str=None) -> typing.Tuple[str, str, str]:
     """重命名本地存在的文件
-
-    :params: file: 文件完整路径 或 相对路径
-    :params: filepath: 文件夹路径
-    :params: filename: 文件名称
+    :params: file: 文件路径
     :params: suffix: 文件后缀名
 
-    note:
-        使用 file 参数之后, filepath 和 filename 将不再生效
-        或者您可以直接使用 filepath 和 filename
+    return:
+    Tuple(rename_file, dirname, basename)
+    """
+    # 绝对路径
+    file = os.path.abspath(file)
+    # 后缀名解析
+    if not isinstance(suffix, str) or not suffix:
+        file_split, suffix = file.rsplit(".", 1), ""
+        if len(file_split) == 2 and len(file_split[-1]) < 6:
+            suffix = file_split[-1]
+    suffix = "." + suffix.strip().removeprefix(".") if suffix.strip() else suffix.strip()
+    # 完整文件路径
+    if not file.endswith(suffix):
+        file += suffix
+
+    if not os.path.isfile(file):
+        return file, *os.path.split(file)
+
+    for index in itertools.count(1):
+        newfile = file.removesuffix(suffix) + f".{index}" + suffix
+        if not os.path.isfile(newfile):
+            break
+    return newfile, *os.path.split(newfile)
+
+
+def rename_folder(folder: str) -> typing.Tuple[str, str, str]:
+    """重命名本地存在的文件夹
+    :params: folder: 文件夹路径
 
     return:
-        Tuple(complete_file, filepath, filename)
+    Tuple(rename_folder, dirname, basename)
     """
-    # 获取完整文件路径
-    if file:
-        file = os.path.abspath(file)
-    else:
-        if not filename:
-            raise ValueError("'rename' 参数 file, filename 必需添加一个 str 数据")
-        if filepath:
-            file = os.path.join(filepath, filename)
-        else:
-            file = os.path.abspath(filename)
-    # 解析suffix
-    if suffix and isinstance(suffix, str):
-        suffix = "." + suffix.removeprefix(".")
-    else:
-        suffix = os.path.basename(file).rsplit(".", 1)
-        if len(suffix) == 2:
-            suffix = "." + suffix[-1]
-        else:
-            suffix = ""
+    folder = os.path.abspath(folder)
 
-    file = file.removesuffix(suffix) + suffix
-    filepath, filename = os.path.split(file)
+    if not os.path.isdir(folder):
+        return folder, *os.path.split(folder)
 
-    # 重命名
     for index in itertools.count(1):
-        if not os.path.isfile(file):
-            filename = os.path.basename(file)
+        new_folder = folder + f".{index}"
+        if not os.path.isdir(new_folder):
             break
-        file = os.path.join(
-            filepath,
-            filename.removesuffix(suffix) \
-            + f".{index}" \
-            + suffix
-        )
-    return file, filepath, filename
+    return new_folder, *os.path.split(new_folder)
 
 
 def human_playtime_pr(
@@ -279,11 +270,12 @@ def human_playtime_pr(
         if playtime is None:
             return None
         raise TypeError(
-            f"human_playtime_pr parameter 'playtime' must be a 'int' or 'float'"
-            f", can't be a {type(playtime).__name__!r}")
-    hour, second   = divmod(round(playtime), 3600)
+            f"'playtime' must be a 'int' or 'float', got {type(playtime).__name__!r}")
+
+    symbol, playtime = "-" if playtime < 0 else "", round(abs(playtime))
+    hour, second = divmod(playtime, 3600)
     minute, second = divmod(second, 60)
-    return f"{hour}:{minute:0>2}:{second:0>2}"
+    return f"{symbol}{hour}:{minute:0>2}:{second:0>2}"
 
 
 def hash256(
@@ -297,3 +289,32 @@ def hash256(
     if isinstance(data, str):
         data = data.encode(encoding)
     return hashlib.sha256(data).hexdigest()
+
+
+def transfer_lazyloader(code: str, /):
+    """python模块转换懒加载"""
+    def repl_string(match):
+
+        module_name  = match.group("module_name")
+        package_name = match.group("package_name")
+        import_name  = match.group("import_name")
+
+        if module_name:
+            string = "\n".join(
+                [
+                    f'{item.strip()} = LazyLoader("{item.strip()}", globals(), "{package_name}.{item.strip()}")'
+                    for item in module_name.split(",")
+                ]
+            )
+        elif import_name:
+            string = "\n".join(
+                [
+                    f'{item.strip()} = LazyLoader("{item.strip()}", globals())'
+                    for item in import_name.split(",")
+                ]
+            )
+        return string
+
+    pattern = re.compile(r"^from\s+?(?P<package_name>.*?)\s+?import\s+?(?P<module_name>.*?)\s*?$|^import\s+?(?P<import_name>.*?)\s*?$", flags=re.M)
+    lazy_loader = "from pyxk.lazy_loader import LazyLoader\n\n"
+    return lazy_loader + pattern.sub(repl=repl_string, string=code)
